# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/detection_instance_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import detection_api_pb2 as fsai__grpc__api_dot_protos_dot_detection__api__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/detection_instance_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1fsai_grpc_api/protos/detection_instance_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(fsai_grpc_api/protos/detection_api.proto\x1a fsai_grpc_api/protos/utils.proto\"\xe5\x03\n\x11\x44\x65tectionInstance\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\x12\x0f\n\x07part_id\x18\x03 \x01(\x05\x12\x10\n\x08image_id\x18\x04 \x01(\x05\x12\x14\n\x0c\x64\x65tection_id\x18\x05 \x01(\x05\x12\x11\n\tsource_id\x18\x06 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x07 \x01(\x0b\x32\x08.GeoBbox\x12\r\n\x05score\x18\x08 \x01(\x02\x12\x0e\n\x06height\x18\t \x01(\x02\x12/\n\x0b\x64\x65tected_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x63\x61tegory_id\x18\x0e \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x0f \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x10 \x01(\x0b\x32\t.GeoPoint\"F\n2CacheDetectionInstancesDataByImageIdRequestRequest\x12\x10\n\x08image_id\x18\x01 \x01(\x05\"\x88\x01\n3CacheDetectionInstancesDataByImageIdRequestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"z\n)FindOrCreateHumanDetectionInstanceRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"~\n*FindOrCreateHumanDetectionInstanceResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"|\n+FindOrCreateMachineDetectionInstanceRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"\x80\x01\n,FindOrCreateMachineDetectionInstanceResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"W\n%GetDetectionInstancesByImageIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"{\n&GetDetectionInstancesByImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"W\n%UpdateDetectionInstanceGeoBboxRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"z\n&UpdateDetectionInstanceGeoBboxResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"T\n\"DeleteDetectionInstanceByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n#DeleteDetectionInstanceByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"U\n#GetDetectionInstanceDataByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"M\n$GetDetectionInstanceDataByIdResponse\x12%\n\x1d\x64\x65tection_instance_data_bytes\x18\x01 \x01(\x0c\"j\n\'TransitionDetectionInstanceStateRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x0f\n\x07trigger\x18\x02 \x01(\t\"\x8b\x01\n(TransitionDetectionInstanceStateResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\r\n\x05state\x18\x02 \x01(\t\x12.\n\x12\x64\x65tection_instance\x18\x03 \x01(\x0b\x32\x12.DetectionInstance\"U\n#GetDetectionInstanceBboxByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n$GetDetectionInstanceBboxByIdResponse\x12\r\n\x05min_x\x18\x01 \x01(\x05\x12\r\n\x05max_x\x18\x02 \x01(\x05\x12\r\n\x05min_y\x18\x03 \x01(\x05\x12\r\n\x05max_y\x18\x04 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x05 \x01(\x05\"\x9c\x01\n\'UpdateDetectionInstanceGeoPointsRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"|\n(UpdateDetectionInstanceGeoPointsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance2\xd4\t\n\x14\x44\x65tectionInstanceApi\x12\x98\x01\n+CacheDetectionInstancesDataByImageIdRequest\x12\x33.CacheDetectionInstancesDataByImageIdRequestRequest\x1a\x34.CacheDetectionInstancesDataByImageIdRequestResponse\x12h\n\x1b\x44\x65leteDetectionInstanceById\x12#.DeleteDetectionInstanceByIdRequest\x1a$.DeleteDetectionInstanceByIdResponse\x12}\n\"FindOrCreateHumanDetectionInstance\x12*.FindOrCreateHumanDetectionInstanceRequest\x1a+.FindOrCreateHumanDetectionInstanceResponse\x12\x83\x01\n$FindOrCreateMachineDetectionInstance\x12,.FindOrCreateMachineDetectionInstanceRequest\x1a-.FindOrCreateMachineDetectionInstanceResponse\x12m\n\x1cGetDetectionInstanceDataById\x12$.GetDetectionInstanceDataByIdRequest\x1a%.GetDetectionInstanceDataByIdResponse0\x01\x12q\n\x1eGetDetectionInstancesByImageId\x12&.GetDetectionInstancesByImageIdRequest\x1a\'.GetDetectionInstancesByImageIdResponse\x12w\n TransitionDetectionInstanceState\x12(.TransitionDetectionInstanceStateRequest\x1a).TransitionDetectionInstanceStateResponse\x12q\n\x1eUpdateDetectionInstanceGeoBbox\x12&.UpdateDetectionInstanceGeoBboxRequest\x1a\'.UpdateDetectionInstanceGeoBboxResponse\x12k\n\x1cGetDetectionInstanceBboxById\x12$.GetDetectionInstanceBboxByIdRequest\x1a%.GetDetectionInstanceBboxByIdResponse\x12w\n UpdateDetectionInstanceGeoPoints\x12(.UpdateDetectionInstanceGeoPointsRequest\x1a).UpdateDetectionInstanceGeoPointsResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_detection__api__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_DETECTIONINSTANCE = _descriptor.Descriptor(
  name='DetectionInstance',
  full_name='DetectionInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='DetectionInstance.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='DetectionInstance.workflow_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='part_id', full_name='DetectionInstance.part_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='DetectionInstance.image_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_id', full_name='DetectionInstance.detection_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='DetectionInstance.source_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_bbox', full_name='DetectionInstance.geo_bbox', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='DetectionInstance.score', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='DetectionInstance.height', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detected_at', full_name='DetectionInstance.detected_at', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='DetectionInstance.created_at', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='DetectionInstance.updated_at', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='DetectionInstance.deleted_at', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_id', full_name='DetectionInstance.category_id', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_start', full_name='DetectionInstance.geo_point_shadow_start', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_end', full_name='DetectionInstance.geo_point_shadow_end', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=648,
)


_CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTREQUEST = _descriptor.Descriptor(
  name='CacheDetectionInstancesDataByImageIdRequestRequest',
  full_name='CacheDetectionInstancesDataByImageIdRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='CacheDetectionInstancesDataByImageIdRequestRequest.image_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=720,
)


_CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTRESPONSE = _descriptor.Descriptor(
  name='CacheDetectionInstancesDataByImageIdRequestResponse',
  full_name='CacheDetectionInstancesDataByImageIdRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CacheDetectionInstancesDataByImageIdRequestResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instances', full_name='CacheDetectionInstancesDataByImageIdRequestResponse.detection_instances', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=859,
)


_FINDORCREATEHUMANDETECTIONINSTANCEREQUEST = _descriptor.Descriptor(
  name='FindOrCreateHumanDetectionInstanceRequest',
  full_name='FindOrCreateHumanDetectionInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateHumanDetectionInstanceRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection', full_name='FindOrCreateHumanDetectionInstanceRequest.detection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=983,
)


_FINDORCREATEHUMANDETECTIONINSTANCERESPONSE = _descriptor.Descriptor(
  name='FindOrCreateHumanDetectionInstanceResponse',
  full_name='FindOrCreateHumanDetectionInstanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateHumanDetectionInstanceResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateHumanDetectionInstanceResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=985,
  serialized_end=1111,
)


_FINDORCREATEMACHINEDETECTIONINSTANCEREQUEST = _descriptor.Descriptor(
  name='FindOrCreateMachineDetectionInstanceRequest',
  full_name='FindOrCreateMachineDetectionInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateMachineDetectionInstanceRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection', full_name='FindOrCreateMachineDetectionInstanceRequest.detection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1113,
  serialized_end=1237,
)


_FINDORCREATEMACHINEDETECTIONINSTANCERESPONSE = _descriptor.Descriptor(
  name='FindOrCreateMachineDetectionInstanceResponse',
  full_name='FindOrCreateMachineDetectionInstanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateMachineDetectionInstanceResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateMachineDetectionInstanceResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1240,
  serialized_end=1368,
)


_GETDETECTIONINSTANCESBYIMAGEIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstancesByImageIdRequest',
  full_name='GetDetectionInstancesByImageIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstancesByImageIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1370,
  serialized_end=1457,
)


_GETDETECTIONINSTANCESBYIMAGEIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstancesByImageIdResponse',
  full_name='GetDetectionInstancesByImageIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetDetectionInstancesByImageIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instances', full_name='GetDetectionInstancesByImageIdResponse.detection_instances', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1459,
  serialized_end=1582,
)


_UPDATEDETECTIONINSTANCEGEOBBOXREQUEST = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoBboxRequest',
  full_name='UpdateDetectionInstanceGeoBboxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoBboxRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1584,
  serialized_end=1671,
)


_UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoBboxResponse',
  full_name='UpdateDetectionInstanceGeoBboxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateDetectionInstanceGeoBboxResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoBboxResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1673,
  serialized_end=1795,
)


_DELETEDETECTIONINSTANCEBYIDREQUEST = _descriptor.Descriptor(
  name='DeleteDetectionInstanceByIdRequest',
  full_name='DeleteDetectionInstanceByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='DeleteDetectionInstanceByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=1881,
)


_DELETEDETECTIONINSTANCEBYIDRESPONSE = _descriptor.Descriptor(
  name='DeleteDetectionInstanceByIdResponse',
  full_name='DeleteDetectionInstanceByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteDetectionInstanceByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='DeleteDetectionInstanceByIdResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1883,
  serialized_end=2002,
)


_GETDETECTIONINSTANCEDATABYIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstanceDataByIdRequest',
  full_name='GetDetectionInstanceDataByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceDataByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2004,
  serialized_end=2089,
)


_GETDETECTIONINSTANCEDATABYIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstanceDataByIdResponse',
  full_name='GetDetectionInstanceDataByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance_data_bytes', full_name='GetDetectionInstanceDataByIdResponse.detection_instance_data_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2091,
  serialized_end=2168,
)


_TRANSITIONDETECTIONINSTANCESTATEREQUEST = _descriptor.Descriptor(
  name='TransitionDetectionInstanceStateRequest',
  full_name='TransitionDetectionInstanceStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='TransitionDetectionInstanceStateRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='TransitionDetectionInstanceStateRequest.trigger', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2170,
  serialized_end=2276,
)


_TRANSITIONDETECTIONINSTANCESTATERESPONSE = _descriptor.Descriptor(
  name='TransitionDetectionInstanceStateResponse',
  full_name='TransitionDetectionInstanceStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='TransitionDetectionInstanceStateResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='TransitionDetectionInstanceStateResponse.state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='TransitionDetectionInstanceStateResponse.detection_instance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2279,
  serialized_end=2418,
)


_GETDETECTIONINSTANCEBBOXBYIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstanceBboxByIdRequest',
  full_name='GetDetectionInstanceBboxByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceBboxByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2420,
  serialized_end=2505,
)


_GETDETECTIONINSTANCEBBOXBYIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstanceBboxByIdResponse',
  full_name='GetDetectionInstanceBboxByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_x', full_name='GetDetectionInstanceBboxByIdResponse.min_x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_x', full_name='GetDetectionInstanceBboxByIdResponse.max_x', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_y', full_name='GetDetectionInstanceBboxByIdResponse.min_y', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_y', full_name='GetDetectionInstanceBboxByIdResponse.max_y', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_id', full_name='GetDetectionInstanceBboxByIdResponse.category_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2507,
  serialized_end=2626,
)


_UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoPointsRequest',
  full_name='UpdateDetectionInstanceGeoPointsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance_id', full_name='UpdateDetectionInstanceGeoPointsRequest.detection_instance_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_start', full_name='UpdateDetectionInstanceGeoPointsRequest.geo_point_shadow_start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_end', full_name='UpdateDetectionInstanceGeoPointsRequest.geo_point_shadow_end', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2629,
  serialized_end=2785,
)


_UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoPointsResponse',
  full_name='UpdateDetectionInstanceGeoPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateDetectionInstanceGeoPointsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoPointsResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2787,
  serialized_end=2911,
)

_DETECTIONINSTANCE.fields_by_name['geo_bbox'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOBBOX
_DETECTIONINSTANCE.fields_by_name['detected_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['geo_point_shadow_start'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_DETECTIONINSTANCE.fields_by_name['geo_point_shadow_end'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTRESPONSE.fields_by_name['detection_instances'].message_type = _DETECTIONINSTANCE
_FINDORCREATEHUMANDETECTIONINSTANCEREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_FINDORCREATEHUMANDETECTIONINSTANCEREQUEST.fields_by_name['detection'].message_type = fsai__grpc__api_dot_protos_dot_detection__api__pb2._DETECTION
_FINDORCREATEHUMANDETECTIONINSTANCERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEHUMANDETECTIONINSTANCERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_FINDORCREATEMACHINEDETECTIONINSTANCEREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_FINDORCREATEMACHINEDETECTIONINSTANCEREQUEST.fields_by_name['detection'].message_type = fsai__grpc__api_dot_protos_dot_detection__api__pb2._DETECTION
_FINDORCREATEMACHINEDETECTIONINSTANCERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEMACHINEDETECTIONINSTANCERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCESBYIMAGEIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCESBYIMAGEIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETDETECTIONINSTANCESBYIMAGEIDRESPONSE.fields_by_name['detection_instances'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOBBOXREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_DELETEDETECTIONINSTANCEBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_DELETEDETECTIONINSTANCEBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_DELETEDETECTIONINSTANCEBYIDRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCEDATABYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_TRANSITIONDETECTIONINSTANCESTATEREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_TRANSITIONDETECTIONINSTANCESTATERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_TRANSITIONDETECTIONINSTANCESTATERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCEBBOXBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST.fields_by_name['geo_point_shadow_start'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST.fields_by_name['geo_point_shadow_end'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
DESCRIPTOR.message_types_by_name['DetectionInstance'] = _DETECTIONINSTANCE
DESCRIPTOR.message_types_by_name['CacheDetectionInstancesDataByImageIdRequestRequest'] = _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTREQUEST
DESCRIPTOR.message_types_by_name['CacheDetectionInstancesDataByImageIdRequestResponse'] = _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['FindOrCreateHumanDetectionInstanceRequest'] = _FINDORCREATEHUMANDETECTIONINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateHumanDetectionInstanceResponse'] = _FINDORCREATEHUMANDETECTIONINSTANCERESPONSE
DESCRIPTOR.message_types_by_name['FindOrCreateMachineDetectionInstanceRequest'] = _FINDORCREATEMACHINEDETECTIONINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateMachineDetectionInstanceResponse'] = _FINDORCREATEMACHINEDETECTIONINSTANCERESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstancesByImageIdRequest'] = _GETDETECTIONINSTANCESBYIMAGEIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstancesByImageIdResponse'] = _GETDETECTIONINSTANCESBYIMAGEIDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoBboxRequest'] = _UPDATEDETECTIONINSTANCEGEOBBOXREQUEST
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoBboxResponse'] = _UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDetectionInstanceByIdRequest'] = _DELETEDETECTIONINSTANCEBYIDREQUEST
DESCRIPTOR.message_types_by_name['DeleteDetectionInstanceByIdResponse'] = _DELETEDETECTIONINSTANCEBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstanceDataByIdRequest'] = _GETDETECTIONINSTANCEDATABYIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstanceDataByIdResponse'] = _GETDETECTIONINSTANCEDATABYIDRESPONSE
DESCRIPTOR.message_types_by_name['TransitionDetectionInstanceStateRequest'] = _TRANSITIONDETECTIONINSTANCESTATEREQUEST
DESCRIPTOR.message_types_by_name['TransitionDetectionInstanceStateResponse'] = _TRANSITIONDETECTIONINSTANCESTATERESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstanceBboxByIdRequest'] = _GETDETECTIONINSTANCEBBOXBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstanceBboxByIdResponse'] = _GETDETECTIONINSTANCEBBOXBYIDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoPointsRequest'] = _UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoPointsResponse'] = _UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DetectionInstance = _reflection.GeneratedProtocolMessageType('DetectionInstance', (_message.Message,), {
  'DESCRIPTOR' : _DETECTIONINSTANCE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DetectionInstance)
  })
_sym_db.RegisterMessage(DetectionInstance)

CacheDetectionInstancesDataByImageIdRequestRequest = _reflection.GeneratedProtocolMessageType('CacheDetectionInstancesDataByImageIdRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:CacheDetectionInstancesDataByImageIdRequestRequest)
  })
_sym_db.RegisterMessage(CacheDetectionInstancesDataByImageIdRequestRequest)

CacheDetectionInstancesDataByImageIdRequestResponse = _reflection.GeneratedProtocolMessageType('CacheDetectionInstancesDataByImageIdRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:CacheDetectionInstancesDataByImageIdRequestResponse)
  })
_sym_db.RegisterMessage(CacheDetectionInstancesDataByImageIdRequestResponse)

FindOrCreateHumanDetectionInstanceRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateHumanDetectionInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEHUMANDETECTIONINSTANCEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateHumanDetectionInstanceRequest)
  })
_sym_db.RegisterMessage(FindOrCreateHumanDetectionInstanceRequest)

FindOrCreateHumanDetectionInstanceResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateHumanDetectionInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEHUMANDETECTIONINSTANCERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateHumanDetectionInstanceResponse)
  })
_sym_db.RegisterMessage(FindOrCreateHumanDetectionInstanceResponse)

FindOrCreateMachineDetectionInstanceRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateMachineDetectionInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEMACHINEDETECTIONINSTANCEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateMachineDetectionInstanceRequest)
  })
_sym_db.RegisterMessage(FindOrCreateMachineDetectionInstanceRequest)

FindOrCreateMachineDetectionInstanceResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateMachineDetectionInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEMACHINEDETECTIONINSTANCERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateMachineDetectionInstanceResponse)
  })
_sym_db.RegisterMessage(FindOrCreateMachineDetectionInstanceResponse)

GetDetectionInstancesByImageIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstancesByImageIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCESBYIMAGEIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstancesByImageIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstancesByImageIdRequest)

GetDetectionInstancesByImageIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstancesByImageIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCESBYIMAGEIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstancesByImageIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstancesByImageIdResponse)

UpdateDetectionInstanceGeoBboxRequest = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoBboxRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOBBOXREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoBboxRequest)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoBboxRequest)

UpdateDetectionInstanceGeoBboxResponse = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoBboxResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoBboxResponse)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoBboxResponse)

DeleteDetectionInstanceByIdRequest = _reflection.GeneratedProtocolMessageType('DeleteDetectionInstanceByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDETECTIONINSTANCEBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteDetectionInstanceByIdRequest)
  })
_sym_db.RegisterMessage(DeleteDetectionInstanceByIdRequest)

DeleteDetectionInstanceByIdResponse = _reflection.GeneratedProtocolMessageType('DeleteDetectionInstanceByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDETECTIONINSTANCEBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteDetectionInstanceByIdResponse)
  })
_sym_db.RegisterMessage(DeleteDetectionInstanceByIdResponse)

GetDetectionInstanceDataByIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceDataByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEDATABYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceDataByIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstanceDataByIdRequest)

GetDetectionInstanceDataByIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceDataByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEDATABYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceDataByIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstanceDataByIdResponse)

TransitionDetectionInstanceStateRequest = _reflection.GeneratedProtocolMessageType('TransitionDetectionInstanceStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONDETECTIONINSTANCESTATEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionDetectionInstanceStateRequest)
  })
_sym_db.RegisterMessage(TransitionDetectionInstanceStateRequest)

TransitionDetectionInstanceStateResponse = _reflection.GeneratedProtocolMessageType('TransitionDetectionInstanceStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONDETECTIONINSTANCESTATERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionDetectionInstanceStateResponse)
  })
_sym_db.RegisterMessage(TransitionDetectionInstanceStateResponse)

GetDetectionInstanceBboxByIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceBboxByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEBBOXBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceBboxByIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstanceBboxByIdRequest)

GetDetectionInstanceBboxByIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceBboxByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEBBOXBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceBboxByIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstanceBboxByIdResponse)

UpdateDetectionInstanceGeoPointsRequest = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoPointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoPointsRequest)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoPointsRequest)

UpdateDetectionInstanceGeoPointsResponse = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoPointsResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoPointsResponse)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoPointsResponse)



_DETECTIONINSTANCEAPI = _descriptor.ServiceDescriptor(
  name='DetectionInstanceApi',
  full_name='DetectionInstanceApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2914,
  serialized_end=4150,
  methods=[
  _descriptor.MethodDescriptor(
    name='CacheDetectionInstancesDataByImageIdRequest',
    full_name='DetectionInstanceApi.CacheDetectionInstancesDataByImageIdRequest',
    index=0,
    containing_service=None,
    input_type=_CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTREQUEST,
    output_type=_CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDetectionInstanceById',
    full_name='DetectionInstanceApi.DeleteDetectionInstanceById',
    index=1,
    containing_service=None,
    input_type=_DELETEDETECTIONINSTANCEBYIDREQUEST,
    output_type=_DELETEDETECTIONINSTANCEBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindOrCreateHumanDetectionInstance',
    full_name='DetectionInstanceApi.FindOrCreateHumanDetectionInstance',
    index=2,
    containing_service=None,
    input_type=_FINDORCREATEHUMANDETECTIONINSTANCEREQUEST,
    output_type=_FINDORCREATEHUMANDETECTIONINSTANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindOrCreateMachineDetectionInstance',
    full_name='DetectionInstanceApi.FindOrCreateMachineDetectionInstance',
    index=3,
    containing_service=None,
    input_type=_FINDORCREATEMACHINEDETECTIONINSTANCEREQUEST,
    output_type=_FINDORCREATEMACHINEDETECTIONINSTANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstanceDataById',
    full_name='DetectionInstanceApi.GetDetectionInstanceDataById',
    index=4,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCEDATABYIDREQUEST,
    output_type=_GETDETECTIONINSTANCEDATABYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstancesByImageId',
    full_name='DetectionInstanceApi.GetDetectionInstancesByImageId',
    index=5,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCESBYIMAGEIDREQUEST,
    output_type=_GETDETECTIONINSTANCESBYIMAGEIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransitionDetectionInstanceState',
    full_name='DetectionInstanceApi.TransitionDetectionInstanceState',
    index=6,
    containing_service=None,
    input_type=_TRANSITIONDETECTIONINSTANCESTATEREQUEST,
    output_type=_TRANSITIONDETECTIONINSTANCESTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDetectionInstanceGeoBbox',
    full_name='DetectionInstanceApi.UpdateDetectionInstanceGeoBbox',
    index=7,
    containing_service=None,
    input_type=_UPDATEDETECTIONINSTANCEGEOBBOXREQUEST,
    output_type=_UPDATEDETECTIONINSTANCEGEOBBOXRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstanceBboxById',
    full_name='DetectionInstanceApi.GetDetectionInstanceBboxById',
    index=8,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCEBBOXBYIDREQUEST,
    output_type=_GETDETECTIONINSTANCEBBOXBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDetectionInstanceGeoPoints',
    full_name='DetectionInstanceApi.UpdateDetectionInstanceGeoPoints',
    index=9,
    containing_service=None,
    input_type=_UPDATEDETECTIONINSTANCEGEOPOINTSREQUEST,
    output_type=_UPDATEDETECTIONINSTANCEGEOPOINTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DETECTIONINSTANCEAPI)

DESCRIPTOR.services_by_name['DetectionInstanceApi'] = _DETECTIONINSTANCEAPI

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import detection_instance_api_pb2 as fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2


class DetectionInstanceApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CacheDetectionInstancesDataByImageIdRequest = channel.unary_unary(
                '/DetectionInstanceApi/CacheDetectionInstancesDataByImageIdRequest',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestResponse.FromString,
                )
        self.DeleteDetectionInstanceById = channel.unary_unary(
                '/DetectionInstanceApi/DeleteDetectionInstanceById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
                )
        self.FindOrCreateHumanDetectionInstance = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateHumanDetectionInstance',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceResponse.FromString,
                )
        self.FindOrCreateMachineDetectionInstance = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateMachineDetectionInstance',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceResponse.FromString,
                )
        self.GetDetectionInstanceDataById = channel.unary_stream(
                '/DetectionInstanceApi/GetDetectionInstanceDataById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
                )
        self.GetDetectionInstancesByImageId = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstancesByImageId',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.FromString,
                )
        self.TransitionDetectionInstanceState = channel.unary_unary(
                '/DetectionInstanceApi/TransitionDetectionInstanceState',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoBbox = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoBbox',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.FromString,
                )
        self.GetDetectionInstanceBboxById = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstanceBboxById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoPoints = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoPoints',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsResponse.FromString,
                )


class DetectionInstanceApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CacheDetectionInstancesDataByImageIdRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDetectionInstanceById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOrCreateHumanDetectionInstance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOrCreateMachineDetectionInstance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceDataById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstancesByImageId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransitionDetectionInstanceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoBbox(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceBboxById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoPoints(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DetectionInstanceApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CacheDetectionInstancesDataByImageIdRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CacheDetectionInstancesDataByImageIdRequest,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestResponse.SerializeToString,
            ),
            'DeleteDetectionInstanceById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDetectionInstanceById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.SerializeToString,
            ),
            'FindOrCreateHumanDetectionInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateHumanDetectionInstance,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceResponse.SerializeToString,
            ),
            'FindOrCreateMachineDetectionInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateMachineDetectionInstance,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceResponse.SerializeToString,
            ),
            'GetDetectionInstanceDataById': grpc.unary_stream_rpc_method_handler(
                    servicer.GetDetectionInstanceDataById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.SerializeToString,
            ),
            'GetDetectionInstancesByImageId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstancesByImageId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.SerializeToString,
            ),
            'TransitionDetectionInstanceState': grpc.unary_unary_rpc_method_handler(
                    servicer.TransitionDetectionInstanceState,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoBbox': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoBbox,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.SerializeToString,
            ),
            'GetDetectionInstanceBboxById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstanceBboxById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoPoints': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoPoints,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DetectionInstanceApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DetectionInstanceApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CacheDetectionInstancesDataByImageIdRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/CacheDetectionInstancesDataByImageIdRequest',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDetectionInstanceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/DeleteDetectionInstanceById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindOrCreateHumanDetectionInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateHumanDetectionInstance',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateHumanDetectionInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindOrCreateMachineDetectionInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateMachineDetectionInstance',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateMachineDetectionInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceDataById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/DetectionInstanceApi/GetDetectionInstanceDataById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstancesByImageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstancesByImageId',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransitionDetectionInstanceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/TransitionDetectionInstanceState',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoBbox(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoBbox',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceBboxById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstanceBboxById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoPoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoPoints',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/user_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/user_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#fsai_grpc_api/protos/user_api.proto\x1a fsai_grpc_api/protos/utils.proto\"P\n\x04User\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05\x66irst\x18\x02 \x01(\t\x12\x0c\n\x04last\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\"(\n\x11\x43reateUserRequest\x12\x13\n\x04user\x18\x01 \x01(\x0b\x32\x05.User\"K\n\x12\x43reateUserResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04user\x18\x02 \x01(\x0b\x32\x05.User\"-\n\x16\x46indUserByEmailRequest\x12\x13\n\x04user\x18\x01 \x01(\x0b\x32\x05.User\"P\n\x17\x46indUserByEmailResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04user\x18\x02 \x01(\x0b\x32\x05.User\":\n\x17\x41uthenticateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"K\n\x18\x41uthenticateUserResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\r\n\x05valid\x18\x02 \x01(\x08\x32\xcf\x01\n\x07UserApi\x12\x35\n\nCreateUser\x12\x12.CreateUserRequest\x1a\x13.CreateUserResponse\x12\x44\n\x0f\x46indUserByEmail\x12\x17.FindUserByEmailRequest\x1a\x18.FindUserByEmailResponse\x12G\n\x10\x41uthenticateUser\x12\x18.AuthenticateUserRequest\x1a\x19.AuthenticateUserResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_USER = _descriptor.Descriptor(
  name='User',
  full_name='User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='User.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first', full_name='User.first', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last', full_name='User.last', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='User.email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='User.password', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=153,
)


_CREATEUSERREQUEST = _descriptor.Descriptor(
  name='CreateUserRequest',
  full_name='CreateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='CreateUserRequest.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=195,
)


_CREATEUSERRESPONSE = _descriptor.Descriptor(
  name='CreateUserResponse',
  full_name='CreateUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CreateUserResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='CreateUserResponse.user', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=272,
)


_FINDUSERBYEMAILREQUEST = _descriptor.Descriptor(
  name='FindUserByEmailRequest',
  full_name='FindUserByEmailRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='FindUserByEmailRequest.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=319,
)


_FINDUSERBYEMAILRESPONSE = _descriptor.Descriptor(
  name='FindUserByEmailResponse',
  full_name='FindUserByEmailResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindUserByEmailResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='FindUserByEmailResponse.user', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=401,
)


_AUTHENTICATEUSERREQUEST = _descriptor.Descriptor(
  name='AuthenticateUserRequest',
  full_name='AuthenticateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='AuthenticateUserRequest.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='AuthenticateUserRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=461,
)


_AUTHENTICATEUSERRESPONSE = _descriptor.Descriptor(
  name='AuthenticateUserResponse',
  full_name='AuthenticateUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='AuthenticateUserResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid', full_name='AuthenticateUserResponse.valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=538,
)

_CREATEUSERREQUEST.fields_by_name['user'].message_type = _USER
_CREATEUSERRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CREATEUSERRESPONSE.fields_by_name['user'].message_type = _USER
_FINDUSERBYEMAILREQUEST.fields_by_name['user'].message_type = _USER
_FINDUSERBYEMAILRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDUSERBYEMAILRESPONSE.fields_by_name['user'].message_type = _USER
_AUTHENTICATEUSERRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['CreateUserRequest'] = _CREATEUSERREQUEST
DESCRIPTOR.message_types_by_name['CreateUserResponse'] = _CREATEUSERRESPONSE
DESCRIPTOR.message_types_by_name['FindUserByEmailRequest'] = _FINDUSERBYEMAILREQUEST
DESCRIPTOR.message_types_by_name['FindUserByEmailResponse'] = _FINDUSERBYEMAILRESPONSE
DESCRIPTOR.message_types_by_name['AuthenticateUserRequest'] = _AUTHENTICATEUSERREQUEST
DESCRIPTOR.message_types_by_name['AuthenticateUserResponse'] = _AUTHENTICATEUSERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'fsai_grpc_api.protos.user_api_pb2'
  # @@protoc_insertion_point(class_scope:User)
  })
_sym_db.RegisterMessage(User)

CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'fsai_grpc_api.protos.user_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

CreateUserResponse = _reflection.GeneratedProtocolMessageType('CreateUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.user_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateUserResponse)
  })
_sym_db.RegisterMessage(CreateUserResponse)

FindUserByEmailRequest = _reflection.GeneratedProtocolMessageType('FindUserByEmailRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDUSERBYEMAILREQUEST,
  '__module__' : 'fsai_grpc_api.protos.user_api_pb2'
  # @@protoc_insertion_point(class_scope:FindUserByEmailRequest)
  })
_sym_db.RegisterMessage(FindUserByEmailRequest)

FindUserByEmailResponse = _reflection.GeneratedProtocolMessageType('FindUserByEmailResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDUSERBYEMAILRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.user_api_pb2'
  # @@protoc_insertion_point(class_scope:FindUserByEmailResponse)
  })
_sym_db.RegisterMessage(FindUserByEmailResponse)

AuthenticateUserRequest = _reflection.GeneratedProtocolMessageType('AuthenticateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEUSERREQUEST,
  '__module__' : 'fsai_grpc_api.protos.user_api_pb2'
  # @@protoc_insertion_point(class_scope:AuthenticateUserRequest)
  })
_sym_db.RegisterMessage(AuthenticateUserRequest)

AuthenticateUserResponse = _reflection.GeneratedProtocolMessageType('AuthenticateUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEUSERRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.user_api_pb2'
  # @@protoc_insertion_point(class_scope:AuthenticateUserResponse)
  })
_sym_db.RegisterMessage(AuthenticateUserResponse)



_USERAPI = _descriptor.ServiceDescriptor(
  name='UserApi',
  full_name='UserApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=541,
  serialized_end=748,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateUser',
    full_name='UserApi.CreateUser',
    index=0,
    containing_service=None,
    input_type=_CREATEUSERREQUEST,
    output_type=_CREATEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindUserByEmail',
    full_name='UserApi.FindUserByEmail',
    index=1,
    containing_service=None,
    input_type=_FINDUSERBYEMAILREQUEST,
    output_type=_FINDUSERBYEMAILRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AuthenticateUser',
    full_name='UserApi.AuthenticateUser',
    index=2,
    containing_service=None,
    input_type=_AUTHENTICATEUSERREQUEST,
    output_type=_AUTHENTICATEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_USERAPI)

DESCRIPTOR.services_by_name['UserApi'] = _USERAPI

# @@protoc_insertion_point(module_scope)
